/*
 * Avoid conflicts with existing md5 code by building names in a unique
 * fashion.
 */
#define MD5NS(x) webbasemd5_##x

/* Define if you have the z library (-lz).  */
#undef HAVE_LIBZ

/* Define if you have the <zlib.h> header file.  */
#undef HAVE_ZLIB_H

/* Is language recognition available */
#undef LANGREC

/* Define if you have the decodage library (-ldecodage).  */
#undef HAVE_LIBDECODAGE

/* Define if you have the <decodage_usr.h> header file.  */
#undef HAVE_DECODAGE_USR_H

/* Is mifluz available */
#undef MIFLUZ

/* Define if you have the mifluz library (-lmifluz).  */
#undef HAVE_LIBMIFLUZ

/* Define if you have the <mifluz.h> header file.  */
#undef HAVE_MIFLUZ_H

/* Define if you have the mysqlclient library (-lmysqlclient).  */
#undef HAVE_LIBMYSQLCLIENT

/* Define if you have the <mysql.h> header file.  */
#undef HAVE_MYSQL_H

/* Define if tables must be split using MERGE to unite them.  */
#undef TABLE_SPLIT

/* BSD style signals ? */
#undef HAVE_BSD_SIGNALS

/* Posix style signals ? */
#undef HAVE_POSIX_SIGNALS

/* USG style signals ? */
#undef HAVE_USG_SIGHOLD

/* Defined if signal handler returns void */
#undef VOID_SIGHANDLER

@TOP@

/* Type of second argument of getsockname */
#undef GETSOCKNAME_ARG2

/* Type of third argument of getsockname */
#undef GETSOCKNAME_ARG3

/* Type of second argument of accept */
#undef ACCEPT_ARG2

/* Type of third argument of accept */
#undef ACCEPT_ARG3

/* Type of third argument of getsockopt */
#undef SETSOCKOPT_ARG3

